@@ -3,13 +3,15 @@ Main interface for sagemaker-a2i-runtime service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.sagemaker_a2i_runtime import AugmentedAIRuntimeClient
+    from mypy_boto3_sagemaker_a2i_runtime import AugmentedAIRuntimeClient
 
     session = boto3.Session()
 
     client: AugmentedAIRuntimeClient = boto3.client("sagemaker-a2i-runtime")
     session_client: AugmentedAIRuntimeClient = session.client("sagemaker-a2i-runtime")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
