@@ -3,14 +3,18 @@ Main interface for sagemaker-a2i-runtime service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.sagemaker_a2i_runtime import (
+
+    from mypy_boto3_sagemaker_a2i_runtime import AugmentedAIRuntimeClient
+    from mypy_boto3_sagemaker_a2i_runtime import (
         ListHumanLoopsPaginator,
     )
 
     client: AugmentedAIRuntimeClient = boto3.client("sagemaker-a2i-runtime")
 
     list_human_loops_paginator: ListHumanLoopsPaginator = client.get_paginator("list_human_loops")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
